@@ -412,14 +412,13 @@ ide_buffer_manager_remove_buffer (IdeBufferManager *self,
   IdeFile *file;
   GFile *gfile;
   gint position = -1;
-  gint i;
 
   IDE_ENTRY;
 
   g_return_if_fail (IDE_IS_BUFFER_MANAGER (self));
   g_return_if_fail (IDE_IS_BUFFER (buffer));
 
-  for (i = 0; i < self->buffers->len; i++)
+  for (guint i = 0; i < self->buffers->len; i++)
     {
       if ((gpointer)buffer == g_ptr_array_index (self->buffers, i))
         {
@@ -1537,6 +1536,9 @@ ide_buffer_manager_class_init (IdeBufferManagerClass *klass)
                                             G_SIGNAL_RUN_LAST,
                                             0, NULL, NULL, NULL,
                                             G_TYPE_NONE, 1, IDE_TYPE_BUFFER);
+
+  g_type_ensure (GTK_SOURCE_TYPE_FILE_LOADER);
+  g_type_ensure (GTK_SOURCE_TYPE_FILE_SAVER);
 }
 
 static void
