@@ -41,6 +41,7 @@
 #include "diagnostics/ide-diagnostic.h"
 #include "diagnostics/ide-source-location.h"
 #include "diagnostics/ide-source-range.h"
+#include "plugins/ide-extension-util.h"
 #include "projects/ide-project.h"
 #include "runtimes/ide-runtime.h"
 #include "util/ide-directory-reaper.h"
@@ -569,7 +570,7 @@ ide_build_pipeline_get_phase (IdeBuildPipeline *self)
     return IDE_BUILD_PHASE_NONE;
   else if (self->failed)
     return IDE_BUILD_PHASE_FAILED;
-  else if (self->position < self->pipeline->len)
+  else if ((guint)self->position < self->pipeline->len)
     return g_array_index (self->pipeline, PipelineEntry, self->position).phase & IDE_BUILD_PHASE_MASK;
   else
     return IDE_BUILD_PHASE_FINISHED;
@@ -726,10 +727,10 @@ ide_build_pipeline_load (IdeBuildPipeline *self)
 
   context = ide_object_get_context (IDE_OBJECT (self));
 
-  self->addins = peas_extension_set_new (peas_engine_get_default (),
-                                         IDE_TYPE_BUILD_PIPELINE_ADDIN,
-                                         "context", context,
-                                         NULL);
+  self->addins = ide_extension_set_new (peas_engine_get_default (),
+                                        IDE_TYPE_BUILD_PIPELINE_ADDIN,
+                                        "context", context,
+                                        NULL);
 
   g_signal_connect (self->addins,
                     "extension-added",
@@ -1006,6 +1007,7 @@ ide_build_pipeline_class_init (IdeBuildPipelineClass *klass)
   /**
    * IdeBuildPipeline::started:
    * @self: An #IdeBuildPipeline
+   * @phase: the #IdeBuildPhase for which we are advancing
    *
    * This signal is emitted when the pipeline has started executing in
    * response to ide_build_pipeline_execute_async() being called.
@@ -1015,7 +1017,8 @@ ide_build_pipeline_class_init (IdeBuildPipelineClass *klass)
                                 G_TYPE_FROM_CLASS (klass),
                                 G_SIGNAL_RUN_LAST,
                                 G_CALLBACK (ide_build_pipeline_real_started),
-                                NULL, NULL, NULL, G_TYPE_NONE, 0);
+                                NULL, NULL, NULL,
+                                G_TYPE_NONE, 1, IDE_TYPE_BUILD_PHASE);
 
   /**
    * IdeBuildPipeline::finished:
@@ -1106,6 +1109,10 @@ ide_build_pipeline_try_chain (IdeBuildPipeline *self,
       if (((entry->phase & IDE_BUILD_PHASE_MASK) & self->requested_mask) == 0)
         return;
 
+      /* Skip past the stage if it is disabled. */
+      if (ide_build_stage_get_disabled (entry->stage))
+        continue;
+
       chained = ide_build_stage_chain (stage, entry->stage);
 
       IDE_TRACE_MSG ("Checking if %s chains to stage[%d] (%s) = %s",
@@ -1168,13 +1175,17 @@ ide_build_pipeline_tick_execute (IdeBuildPipeline *self,
    * will handle all of that for us, in cause they call ide_build_stage_pause()
    * during the ::query callback.
    */
-  for (self->position++; self->position < self->pipeline->len; self->position++)
+  for (self->position++; (guint)self->position < self->pipeline->len; self->position++)
     {
       const PipelineEntry *entry = &g_array_index (self->pipeline, PipelineEntry, self->position);
 
       g_assert (entry->stage != NULL);
       g_assert (IDE_IS_BUILD_STAGE (entry->stage));
 
+      /* Ignore the stage if it is disabled */
+      if (ide_build_stage_get_disabled (entry->stage))
+        continue;
+
       if ((entry->phase & IDE_BUILD_PHASE_MASK) & self->requested_mask)
         {
           self->current_stage = entry->stage;
@@ -1423,10 +1434,8 @@ ide_build_pipeline_do_flush (gpointer data)
       }
   }
 
-  /*
-   * Notify any observers that a build (of some sort) is about to start.
-   */
-  g_signal_emit (self, signals [STARTED], 0);
+  /* Notify any observers that a build (of some sort) is about to start. */
+  g_signal_emit (self, signals [STARTED], 0, task_data->phase);
 
   switch (task_data->type)
     {
@@ -1521,12 +1530,6 @@ ide_build_pipeline_connect (IdeBuildPipeline *self,
                         (phase & IDE_BUILD_PHASE_WHENCE_MASK) == IDE_BUILD_PHASE_BEFORE ||
                         (phase & IDE_BUILD_PHASE_WHENCE_MASK) == IDE_BUILD_PHASE_AFTER, 0);
 
-  if G_UNLIKELY (self->position != -1)
-    {
-      g_warning ("Cannot insert stage into pipeline after execution, ignoring");
-      IDE_RETURN (0);
-    }
-
   klass = g_type_class_ref (IDE_TYPE_BUILD_PHASE);
 
   for (guint i = 0; i < klass->n_values; i++)
@@ -1637,7 +1640,7 @@ ide_build_pipeline_request_phase (IdeBuildPipeline *self,
     {
       const GFlagsValue *value = &klass->values[i];
 
-      if (phase == value->value)
+      if ((guint)phase == value->value)
         {
           IDE_TRACE_MSG ("requesting pipeline phase %s", value->value_nick);
           /*
@@ -2329,7 +2332,7 @@ ide_build_pipeline_clean_async (IdeBuildPipeline    *self,
 
       if (value->value & phase)
         {
-          if (value->value < min_phase)
+          if (value->value < (guint)min_phase)
             min_phase = value->value;
         }
     }
