@@ -367,8 +367,17 @@ communicate_result_validate_utf8 (const char            *stream_name,
   if (buffer)
     {
       const char *end;
+      GError *local_error = NULL;
+
       if (!g_output_stream_is_closed (G_OUTPUT_STREAM (buffer)))
-        g_output_stream_close (G_OUTPUT_STREAM (buffer), NULL, NULL);
+        g_output_stream_close (G_OUTPUT_STREAM (buffer), NULL, &local_error);
+
+      if (local_error != NULL)
+        {
+          g_propagate_error (error, local_error);
+          IDE_RETURN (FALSE);
+        }
+
       *return_location = g_memory_output_stream_steal_data (buffer);
       if (!g_utf8_validate (*return_location, -1, &end))
         {
@@ -667,6 +676,8 @@ ide_subprocess_communicate_made_progress (GObject      *source_object,
   gpointer source;
   GTask *task;
 
+  IDE_ENTRY;
+
   g_assert (source_object != NULL);
 
   task = user_data;
@@ -730,6 +741,8 @@ ide_subprocess_communicate_made_progress (GObject      *source_object,
 
   /* And drop the original ref */
   g_object_unref (task);
+
+  IDE_EXIT;
 }
 
 static CommunicateState *
@@ -766,6 +779,14 @@ ide_breakout_subprocess_communicate_internal (IdeBreakoutSubprocess *subprocess,
       g_source_attach (state->cancellable_source, g_main_context_get_thread_default ());
     }
 
+  /* Increment the outstanding ops count, to protect from reentrancy */
+  if (subprocess->stdin_pipe)
+    state->outstanding_ops++;
+  if (subprocess->stdout_pipe)
+    state->outstanding_ops++;
+  if (subprocess->stderr_pipe)
+    state->outstanding_ops++;
+
   if (subprocess->stdin_pipe)
     {
       g_assert (stdin_buf != NULL);
@@ -774,7 +795,6 @@ ide_breakout_subprocess_communicate_internal (IdeBreakoutSubprocess *subprocess,
                                     G_OUTPUT_STREAM_SPLICE_CLOSE_SOURCE | G_OUTPUT_STREAM_SPLICE_CLOSE_TARGET,
                                     G_PRIORITY_DEFAULT, state->cancellable,
                                     ide_subprocess_communicate_made_progress, g_object_ref (task));
-      state->outstanding_ops++;
     }
 
   if (subprocess->stdout_pipe)
@@ -784,7 +804,6 @@ ide_breakout_subprocess_communicate_internal (IdeBreakoutSubprocess *subprocess,
                                     G_OUTPUT_STREAM_SPLICE_CLOSE_SOURCE,
                                     G_PRIORITY_DEFAULT, state->cancellable,
                                     ide_subprocess_communicate_made_progress, g_object_ref (task));
-      state->outstanding_ops++;
     }
 
   if (subprocess->stderr_pipe)
@@ -794,7 +813,6 @@ ide_breakout_subprocess_communicate_internal (IdeBreakoutSubprocess *subprocess,
                                     G_OUTPUT_STREAM_SPLICE_CLOSE_SOURCE,
                                     G_PRIORITY_DEFAULT, state->cancellable,
                                     ide_subprocess_communicate_made_progress, g_object_ref (task));
-      state->outstanding_ops++;
     }
 
   ide_subprocess_wait_async (IDE_SUBPROCESS (subprocess), state->cancellable,
@@ -1098,7 +1116,7 @@ host_command_exited_cb (GDBusConnection *connection,
     IDE_EXIT;
 
   g_variant_get (parameters, "(uu)", &client_pid, &exit_status);
-  if (client_pid != self->client_pid)
+  if (client_pid != (guint32)self->client_pid)
     IDE_EXIT;
 
   locker = g_mutex_locker_new (&self->waiter_mutex);
@@ -1460,7 +1478,7 @@ ide_breakout_subprocess_initable_init (GInitable     *initable,
    * system. We need to ensure our fd_list is sent across for redirecting
    * various standard streams.
    */
-  g_assert_cmpint (3, ==, g_unix_fd_list_get_length (fd_list));
+  g_assert_cmpint (g_unix_fd_list_get_length (fd_list), >=, 3);
   params = g_variant_new ("(^ay^aay@a{uh}@a{ss}u)",
                           self->cwd ?: g_get_home_dir (),
                           self->argv,
