@@ -638,6 +638,12 @@ ide_autotools_build_system_get_builddir (IdeBuildSystem   *build_system,
   return NULL;
 }
 
+static gchar *
+ide_autotools_build_system_get_id (IdeBuildSystem *build_system)
+{
+  return g_strdup ("autotools");
+}
+
 static void
 ide_autotools_build_system_finalize (GObject *object)
 {
@@ -702,6 +708,7 @@ build_system_iface_init (IdeBuildSystemInterface *iface)
   iface->get_builddir = ide_autotools_build_system_get_builddir;
   iface->get_build_targets_async = ide_autotools_build_system_get_build_targets_async;
   iface->get_build_targets_finish = ide_autotools_build_system_get_build_targets_finish;
+  iface->get_id = ide_autotools_build_system_get_id;
 }
 
 static void
