@@ -758,6 +758,85 @@ gbp_flatpak_application_addin_locate_sdk_worker (GTask        *task,
   g_assert (locate->installations != NULL);
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
+  IDE_TRACE_MSG ("Locating SDK for %s/%s/%s",
+                 locate->id, locate->arch, locate->branch);
+
+  /*
+   * First we'll try to resolve things by locating local items. This allows
+   * us to avoid network traffic.
+   */
+
+  for (guint i = 0; i < locate->installations->len; i++)
+    {
+      InstallInfo *info = g_ptr_array_index (locate->installations, i);
+      FlatpakInstallation *installation = info->installation;
+      g_autoptr(GPtrArray) refs = NULL;
+
+      g_assert (FLATPAK_IS_INSTALLATION (installation));
+
+      refs = flatpak_installation_list_installed_refs_by_kind (installation,
+                                                               FLATPAK_REF_KIND_RUNTIME,
+                                                               cancellable, NULL);
+      if (refs == NULL)
+        continue;
+
+      for (guint j = 0; j < refs->len; j++)
+        {
+          FlatpakInstalledRef *ref = g_ptr_array_index (refs, j);
+          const gchar *id = flatpak_ref_get_name (FLATPAK_REF (ref));
+          const gchar *arch = flatpak_ref_get_arch (FLATPAK_REF (ref));
+          const gchar *branch = flatpak_ref_get_branch (FLATPAK_REF (ref));
+
+          if (g_strcmp0 (locate->id, id) == 0 &&
+              g_strcmp0 (locate->arch, arch) == 0 &&
+              g_strcmp0 (locate->branch, branch) == 0)
+            {
+              g_autoptr(GError) error = NULL;
+              g_autoptr(GBytes) bytes = NULL;
+              g_autoptr(GKeyFile) keyfile = NULL;
+              g_autofree gchar *idstr = NULL;
+              const gchar *data;
+              gsize len;
+
+              bytes = flatpak_installed_ref_load_metadata (ref, cancellable, NULL);
+
+              keyfile = g_key_file_new ();
+              data = (gchar *)g_bytes_get_data (bytes, &len);
+
+              if (!g_key_file_load_from_data (keyfile, data, len, 0, &error))
+                {
+                  g_task_return_error (task, g_steal_pointer (&error));
+                  IDE_EXIT;
+                }
+
+              idstr = g_key_file_get_string (keyfile, "Runtime", "sdk", NULL);
+
+              if (idstr != NULL)
+                {
+                  g_auto(GStrv) parts = g_strsplit (idstr, "/", 3);
+
+                  if (g_strv_length (parts) != 3)
+                    {
+                      g_task_return_new_error (task,
+                                               G_IO_ERROR,
+                                               G_IO_ERROR_INVALID_DATA,
+                                               "Invalid runtime id %s",
+                                               idstr);
+                      IDE_EXIT;
+                    }
+
+                  locate->sdk_id = g_strdup (parts[0]);
+                  locate->sdk_arch = g_strdup (parts[1]);
+                  locate->sdk_branch = g_strdup (parts[2]);
+                }
+
+              g_task_return_boolean (task, TRUE);
+
+              IDE_EXIT;
+            }
+        }
+    }
+
   /*
    * Look through all of our remote refs and see if we find a match for
    * the runtime for which we need to locate the SDK. Afterwards, we need
@@ -860,6 +939,11 @@ gbp_flatpak_application_addin_locate_sdk_worker (GTask        *task,
         }
     }
 
+  g_task_return_new_error (task,
+                           G_IO_ERROR,
+                           G_IO_ERROR_NOT_FOUND,
+                           "Failed to locate corresponding SDK");
+
   IDE_EXIT;
 }
 
@@ -985,3 +1069,85 @@ gbp_flatpak_application_addin_get_deploy_dir (GbpFlatpakApplicationAddin *self,
 
   return NULL;
 }
+
+static void
+gbp_flatpak_application_addin_check_sysdeps_cb (GObject      *object,
+                                                GAsyncResult *result,
+                                                gpointer      user_data)
+{
+  IdeSubprocess *subprocess = (IdeSubprocess *)object;
+  g_autoptr(GTask) task = user_data;
+  g_autoptr(GError) error = NULL;
+
+  IDE_ENTRY;
+
+  g_return_if_fail (IDE_IS_SUBPROCESS (subprocess));
+  g_return_if_fail (G_IS_ASYNC_RESULT (result));
+  g_return_if_fail (G_IS_TASK (task));
+
+  if (!ide_subprocess_wait_check_finish (subprocess, result, &error))
+    g_task_return_error (task, g_steal_pointer (&error));
+  else
+    g_task_return_boolean (task, TRUE);
+
+  IDE_EXIT;
+}
+
+void
+gbp_flatpak_application_addin_check_sysdeps_async (GbpFlatpakApplicationAddin *self,
+                                                   GCancellable               *cancellable,
+                                                   GAsyncReadyCallback         callback,
+                                                   gpointer                    user_data)
+{
+  g_autoptr(IdeSubprocessLauncher) launcher = NULL;
+  g_autoptr(IdeSubprocess) subprocess = NULL;
+  g_autoptr(GTask) task = NULL;
+  g_autoptr(GError) error = NULL;
+
+  IDE_ENTRY;
+
+  g_return_if_fail (GBP_IS_FLATPAK_APPLICATION_ADDIN (self));
+  g_return_if_fail (!cancellable || G_IS_CANCELLABLE (cancellable));
+
+  task = g_task_new (self, cancellable, callback, user_data);
+  g_task_set_source_tag (task, gbp_flatpak_application_addin_check_sysdeps_async);
+
+  launcher = ide_subprocess_launcher_new (G_SUBPROCESS_FLAGS_STDOUT_SILENCE);
+  ide_subprocess_launcher_set_clear_env (launcher, FALSE);
+  ide_subprocess_launcher_set_run_on_host (launcher, TRUE);
+  ide_subprocess_launcher_push_argv (launcher, "which");
+  ide_subprocess_launcher_push_argv (launcher, "flatpak-builder");
+
+  subprocess = ide_subprocess_launcher_spawn (launcher, cancellable, &error);
+
+  if (subprocess == NULL)
+    {
+      g_task_return_error (task, g_steal_pointer (&error));
+      IDE_GOTO (failure);
+    }
+
+  ide_subprocess_wait_check_async (subprocess,
+                                   cancellable,
+                                   gbp_flatpak_application_addin_check_sysdeps_cb,
+                                   g_steal_pointer (&task));
+
+failure:
+  IDE_EXIT;
+}
+
+gboolean
+gbp_flatpak_application_addin_check_sysdeps_finish (GbpFlatpakApplicationAddin  *self,
+                                                    GAsyncResult                *result,
+                                                    GError                     **error)
+{
+  gboolean ret;
+
+  IDE_ENTRY;
+
+  g_return_val_if_fail (GBP_IS_FLATPAK_APPLICATION_ADDIN (self), FALSE);
+  g_return_val_if_fail (G_IS_TASK (result), FALSE);
+
+  ret = g_task_propagate_boolean (G_TASK (result), error);
+
+  IDE_RETURN (ret);
+}
