@@ -90,15 +90,29 @@ main (int   argc,
   int ret;
 
   ide_log_init (TRUE, NULL);
-
   early_verbose_check (&argc, &argv);
 
+  early_ssl_check ();
+
   g_message ("Initializing with Gtk+ version %d.%d.%d.",
              gtk_get_major_version (),
              gtk_get_minor_version (),
              gtk_get_micro_version ());
 
-  early_ssl_check ();
+  /*
+   * FIXME: Work around type registration deadlocks in GObject.
+   *
+   * There seems to be a deadlock in GObject type registration from
+   * different threads based on some different parts of the type system.
+   * This is problematic because we occasionally race during startup in
+   * GZlibDecopmressor's get_type() registration.
+   *
+   * Instead, we'll just deal with this early by registering the type
+   * as soon as possible.
+   *
+   * https://bugzilla.gnome.org/show_bug.cgi?id=779199
+   */
+  g_type_ensure (G_TYPE_ZLIB_DECOMPRESSOR);
 
   app = ide_application_new ();
   ret = g_application_run (G_APPLICATION (app), argc, argv);
